parse_manual_source

Function parse_manual_source 

pub fn parse_manual_source(path: &Path) -> Result<MantDocument, ParseError>
Parse and normalize one located man or mdoc source file.

Errors

Returns ParseError when the source cannot be opened or parsed.