pub fn parse_tldr_command(command: &str) -> Vec<TldrCommandPart>Expand description
Parse the tldr placeholder extension and choose the long option variant.
pub fn parse_tldr_command(command: &str) -> Vec<TldrCommandPart>Parse the tldr placeholder extension and choose the long option variant.