query

Function query 

pub fn query(request: &QueryRequest) -> Result<QueryBundle, QueryError>
Query the local man database and optional offline tldr caches.

Errors

Returns QueryError for invalid input or when neither source can produce readable content.