pub struct ManualPage {
pub name: String,
pub section: String,
pub path: PathBuf,
pub manual_root: PathBuf,
}Expand description
One effective local manual page after path and locale precedence.
Fields
name: Stringsection: Stringpath: PathBufmanual_root: PathBufApproved hierarchy root used to resolve this page’s .so redirects.
The indexed leaf itself may be a file symlink whose target is outside this root. Redirect targets must still remain inside it.