pub fn parse_manual_source(path: &Path) -> Result<MantDocument, ParseError>Expand description
Parse and normalize one located man or mdoc source file.
Errors
Returns ParseError when the source cannot be opened or parsed.
pub fn parse_manual_source(path: &Path) -> Result<MantDocument, ParseError>Parse and normalize one located man or mdoc source file.
Returns ParseError when the source cannot be opened or parsed.